%* lsaf_getabsolutepath                                                                            *;
%*                                                                                                 *;
%* Gets an absolute path for an item relative to the specified base path.                          *;
%*                                                                                                 *;
%* macrotype LSAF                                                                                  *;
%* since 1.5                                                                                       *;
%* exposure external                                                                               *;
%*                                                                                                 *;
%* History                                                                                         *;
%* 2017-01-19  original coding                                                                     *;
%* 2019-02-13  update to 2.1                                                                       *;
%* 2020-07-13  update for refactor of java service hierarchy.                                      *;
%* 2021-08-18  Remove header documentation                                                         *;
%*                                                                                                 *;

%macro lsaf_getabsolutepath(
  lsaf_base_path=,
  lsaf_relative_path=
  ) /des='Get the absolute path relative to the base path.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
          _lsafAbsolutePath_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8
           message         length=$200
           logMsgPrefix    length=$70
           logMsgPrimary   length=$70
           logMsg          length=$300
           absolutePath    length=$2048
    ;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/core/utility/UtilityService") ;
    declare javaobj results("com/sas/lsaf/macro/common/result/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticStringMethod("getAbsolutePath", "%bquote(&lsaf_base_path)", "%bquote(&lsaf_relative_path)", results, absolutePath);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot generate absolute path for &lsaf_relative_path. based on &lsaf_base_path." ;
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" The absolute path was generated: " || kstrip(absolutePath) ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put logMsgPrefix " _lsafAbsolutePath_= " absolutePath;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);
    call symputx("_lsafAbsolutePath_", kstrip(absolutePath)) ;

  run;

%mend lsaf_getabsolutepath;
