%* lsaf_querydistcontextmembership                                                                          *;
%*                                                                                                          *;
%* Extracts the distinct members of a context. The entries to extract are specified in a query that is      *;
%* contained in a SAS data set. The extracted data is stored in a comma-separated values file that is       *;
%* located in your workspace or in the repository.                                                          *;
%*                                                                                                          *;
%* macrotype LSAF                                                                                           *;
%* since 2.4                                                                                                *;
%* exposure external                                                                                        *;
%*                                                                                                          *;
%* History                                                                                                  *;
%* 2020-06-05  initial coding                                                                               *;
%* 2020-11-30  updated for version handling.                                                                *;
%* 2021-03-25  allow for missing query dataset.                                                             *;
%* 2021-08-12  Remove header documentation                                                                  *;
%* 2021-09-20  Remove parameter defaults (DE16775)                                                          *;
%*                                                                                                          *;

%macro lsaf_querydistcontextmembership(
  lsaf_path=,
  lsaf_scope=,
  lsaf_querydataset=,
  lsaf_validateddataset=work.lsafquerydistcontextmembership,
  lsaf_exportlocation=,
  lsaf_exportpath=,
  lsaf_overwrite=,
  lsaf_enableversioning=,
  lsaf_versiontype=,
  lsaf_customversion=,
  lsaf_comment=
  ) /des='Performs a query and returns an output file to a specified location in the SAS Life Science Analytics Framework.';

  %if "&lsaf_validateddataset" EQ "" %then %let lsaf_validateddataset=work.lsafquerydistcontextmembership;
  %let macName = %sysfunc(lowcase(&SYSMACRONAME));
  
  %lsaf_query(lsaf_callingMacro=&macName,
    lsaf_path=&lsaf_path,
    lsaf_scope=&lsaf_scope,
    lsaf_queryMethod=%str(executeDistinctContextMembershipQuery),
    lsaf_returnPathVar=%str(_lsafDistContxtMembershpExpPath_),
    lsaf_querydataset=&lsaf_querydataset,
    lsaf_validateddataset=&lsaf_validateddataset,
    lsaf_exportlocation=&lsaf_exportlocation,
    lsaf_exportpath=&lsaf_exportpath,
    lsaf_overwrite=&lsaf_overwrite,
    lsaf_enableversioning=&lsaf_enableversioning,
    lsaf_versiontype=&lsaf_versiontype,
    lsaf_customversion=&lsaf_customversion,
    lsaf_comment=&lsaf_comment,
    lsaf_allowmissingqueryds=1
  );

%mend lsaf_querydistcontextmembership;
